The functions calculates following measures on the input data:
Measures of Central Tendency: Mean, Median
Measures of Distribution: Count, Proportion
Measures of Dispersion: Min, Max, Quantile, Standard Deviation, Variance
Measures of shape: Skewness, Kurtosis
Addition to these measures, the function provides information on the data type, count on no. of rows,
unique entries and percentage of missing entries
All the above statistics can be generated for the entire data or at a group level. The
variables/variables specified to group_variable parameter splits the data into groups based on
the unique levels of the variable/variables specified and calculates descriptive statistics on each of
these levels.
.